package com.zenjava.resource;

import java.util.ArrayList;
import java.util.List;

/**
 * An abstract base class that provides basic implementation of common methods for ResourceManager implementations.
 */
public abstract class AbstractResourceManager implements ResourceManager
{
    private List<ResourceListener> listeners;

    protected AbstractResourceManager()
    {
        listeners = new ArrayList<ResourceListener>();
    }

    /**
     * Registers the specified listener to receive resource events from this provider.
     *
     * @param listener the listener to be added.
     */
    public void addResourceListener(ResourceListener listener)
    {
        listeners.add(listener);
    }

    /**
     * De-registers the specified listener so that it will no longer receive resource events from this provider.
     *
     * @param listener the listener to be removed.
     */
    public void removeResourceListener(ResourceListener listener)
    {
        listeners.remove(listener);
    }

    /**
     * Notifies all registered ResourceListeners that the specified event occurred.
     *
     * @param event the event to be fired.
     */
    protected void fireResourcesUpdated(ResourceManagerEvent event)
    {
        for (ResourceListener listener : listeners)
        {
            listener.resourcesUpdated(event);
        }
    }
}
