package com.zenjava.resource;

import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

/**
 * Annotation used to indicate that an Enum is to be used as the lookup key for a localised value. If used, the resource
 * provider will use the value of the enum to determine the lookup key.
 */
@Retention(RetentionPolicy.RUNTIME)
public @interface LocalizedEnum
{
    /**
     * If this is specified, the resource provider will use this key as the base key for the lookup. The name of the
     * enum will be appended to this base key to determine the full lookup key.
     *
     * @return optional override of the lookup base key to use.
     */
    String key() default "";

    /**
     * If specified, the resource provider will use the provided mappings as the default values if no localised value
     * could be  found for the Enum with the active Locale.
     *
     * @return optional list of enum mappings to use as the default values.
     */
    LocalizedEnumValue[] mappings() default {};
}
