package com.zenjava.resource;

import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

/**
 * Optional annotation for overriding aspects of an Enum value that is localized.
 */
@Retention(RetentionPolicy.RUNTIME)
public @interface LocalizedEnumValue
{
    /**
     * The name of the annotation that is being overridden. This name must match exactly the name of the Enum.
     *
     * @return the name of the enum to be overridden.
     */
    String enumKey();

    /**
     * The resource provider will use this value if no localized value could be found for the  enum with the active
     * Locale.
     *
     * @return default value to use if no localized value can be found.
     */
    String value();
}
