package com.zenjava.resource;

import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

/**
 * Optional annotation for overriding aspects of a value that is localized.
 */
@Retention(RetentionPolicy.RUNTIME)
public @interface LocalizedValue
{
    /**
     * If this is specified, the resource provider will use this key to lookup the localized resource value, rather than
     * the default.
     *
     * @return optional override of the lookup key to use.
     */
    String key() default "";

    /**
     * If this is specified, the resource provider will use this value if no value could be found for the resource with
     * the active Locale.
     *
     * @return optional default value to use if no localized value can be found.
     */
    String value() default "";
}
