package com.zenjava.resource;

/**
 * Indicates that the implementing class provides events about the status of its managed resources. Resource
 * providers should implement this class and notify all listeners when their managed resources change, in particular
 * when the current Locale changes.
 */
public interface ResourceEventSource
{
    /**
     * Registers the specified listener to receive resource events from this provider.
     *
     * @param listener the listener to be added.
     */
    void addResourceListener(ResourceListener listener);

    /**
     * De-registers the specified listener so that it will no longer receive resource events from this provider.
     *
     * @param listener the listener to be removed.
     */
    void removeResourceListener(ResourceListener listener);
}
