package com.zenjava.resource;

import java.util.Locale;

/**
 * Provides the central access point for accessing localized, text resources based on a specific Locale. Access is
 * provided in an implementation independent way; the underlying implementations may use a ResourceBundle, however this
 * is not required or guaranteed.
 */
public interface ResourceManager extends ResourceEventSource
{
    /**
     * Sets the current Locale for this ResourceManager to use. All subsequent calls to getString will use this locale.
     *
     * @param locale the new locale to use. This must not be null.
     */
    void setLocale(Locale locale);

    /**
     * Retrieves the current Locale that this ResourceManager is configured to use.
     *
     * @return the current Locale for this ResourceManager.
     */
    Locale getLocale();

    /**
     * Retrieves the localized text resource for the specified lookup key using the Locale that this ResourceManager has
     * been configured to use.
     *
     * @param key the lookup key for the value to be localized.
     * @return the value for the specified lookup key based on the Locale this ResourceManager is configured to use.
     */
    String getString(String key);
}
